package com.f1rq.lifemap

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Scaffold
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.tooling.preview.Preview
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.currentBackStackEntryAsState
import androidx.navigation.compose.rememberNavController
import com.f1rq.lifemap.navigationbar.NavigationBar
import com.f1rq.lifemap.screens.ListView
import com.f1rq.lifemap.screens.MapView
import com.f1rq.lifemap.ui.theme.LifeMapTheme
import com.f1rq.lifemap.ui.theme.ActiveNavColor
import com.f1rq.lifemap.ui.theme.InactiveNavColor

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            LifeMapTheme {
                val navController = rememberNavController()

                Scaffold(
                    bottomBar = {
                        val navBackStackEntry = navController.currentBackStackEntryAsState()
                        val currentRoute = navBackStackEntry.value?.destination?.route

                        NavigationBar(
                            onWorldViewTapped = { navController.navigate("mapview") },
                            onListViewTapped = { navController.navigate("listview") },
                            worldViewBackgroundColor = if (currentRoute == "mapview") ActiveNavColor else InactiveNavColor,
                            listViewBackgroundColor = if (currentRoute == "listview") ActiveNavColor else InactiveNavColor
                        )
                    }
                ) { innerPadding ->
                    NavHost(
                        navController = navController,
                        startDestination = "mapview",
                        modifier = Modifier.padding(innerPadding)
                    ) {
                        composable("mapview") { MapView(Modifier) }
                        composable("listview") { ListView(Modifier) }
                    }
                }
            }
        }
    }
}

@Preview(showBackground = true)
@Composable
fun GreetingPreview() {
    LifeMapTheme {
        NavigationBar(
            onWorldViewTapped = {},
            onListViewTapped = {}
        )
    }
}